#[non_exhaustive]pub enum ParseError {
XmlParseError(Error),
DeserializeError(DeError),
Utf8Error(Utf8Error),
IoError(Error),
InvalidFeedFormat(String),
MissingField(String),
}Expand description
Errors that can occur while parsing a feed.
This enum is #[non_exhaustive]: new variants may be added in future minor
releases, so downstream match expressions must include a wildcard arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
XmlParseError(Error)
The input is not well-formed XML.
DeserializeError(DeError)
An entry was well-formed XML but could not be turned into a Feed.
Utf8Error(Utf8Error)
The input contained a byte sequence that is not valid UTF-8.
IoError(Error)
Writing the normalized intermediate XML failed.
InvalidFeedFormat(String)
The document is valid XML but not a valid feed (e.g. an unclosed entry).
MissingField(String)
An entry is missing a field that Feed requires.